@@ -2,8 +2,8 @@ use warnings;
 
 package Git::Hooks::GerritChangeId;
 # ABSTRACT: Git::Hooks plugin to insert a Change-Id in a commit message
-$Git::Hooks::GerritChangeId::VERSION = '3.6.0';
-use v5.16.0;
+$Git::Hooks::GerritChangeId::VERSION = '4.0.0';
+use v5.30.0;
 use utf8;
 use Carp;
 use Log::Any '$log';
@@ -29,7 +29,7 @@ sub gen_change_id {
         [ author    => [qw/var GIT_AUTHOR_IDENT/] ],
         [ committer => [qw/var GIT_COMMITTER_IDENT/] ],
     ) {
-        my $value = eval { $git->run(@{$info->[1]}) };
+        my $value = eval { $git->run($info->[1]->@*) };
         if (defined $value) {
             # It's OK if we can't find value.
             $fh->print("$info->[0] $value");
@@ -103,7 +103,7 @@ Git::Hooks::GerritChangeId - Git::Hooks plugin to insert a Change-Id in a commit
 
 =head1 VERSION
 
-version 3.6.0
+version 4.0.0
 
 =head1 SYNOPSIS
 
@@ -206,7 +206,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2024 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
